@@ -6,7 +6,7 @@ use Moops;
 
 class MarpaX::Languages::M4::Impl::Regexp {
 
-    our $VERSION = '0.009'; # VERSION
+    our $VERSION = '0.010'; # VERSION
 
     our $AUTHORITY = 'cpan:JDDPAUSE'; # AUTHORITY
 
@@ -53,6 +53,11 @@ class MarpaX::Languages::M4::Impl::Regexp {
         my $previousRegcomp = $hasPreviousRegcomp ? $^H{regcomp} : undef;
 
         try {
+            #
+            # Some versions of perl warn, some others don't -;
+            # We are only interested by real failures.
+            #
+            no warnings;
             if ( $regexpType eq 'perl' ) {
                 #
                 # Just make sure this really is perl
@@ -114,6 +119,11 @@ class MarpaX::Languages::M4::Impl::Regexp {
         # lexically scoped, and our scope depend on the engine
         #
         try {
+            #
+            # Some versions of perl warn, some others don't -;
+            # We are only interested by real failures.
+            #
+            no warnings;
             my $regexp = $self->_regexp;
             if ( $self->_regexp_type eq 'perl' ) {
                 #
@@ -249,7 +259,7 @@ MarpaX::Languages::M4::Impl::Regexp - M4 Regexp generic implementation
 
 =head1 VERSION
 
-version 0.009
+version 0.010
 
 =head1 AUTHOR
 
